@@ -21,7 +21,7 @@ def main() -> int:
     basicConfig(format=LOG_FORMAT, level=get_log_level(args))
 
     if args.shuffle:
-        shuffle(args.systems)
+        shuffle(args.system)
 
     try:
         result = multiprocess(Worker, args.system, args.processes, args=args)
